@@ -116,8 +116,9 @@ ares_bool_t ares__timedout(const struct timeval *now,
   }
 
   /* if the full seconds were identical, check the sub second parts */
-  return ((ares_int64_t)now->tv_usec - (ares_int64_t)check->tv_usec) >= 0 ?
-    ARES_TRUE : ARES_FALSE;
+  return ((ares_int64_t)now->tv_usec - (ares_int64_t)check->tv_usec) >= 0
+           ? ARES_TRUE
+           : ARES_FALSE;
 }
 
 /* add the specific number of milliseconds to the time in the first argument */
@@ -139,12 +140,21 @@ static void processfds(ares_channel_t *channel, fd_set *read_fds,
                        ares_socket_t read_fd, fd_set *write_fds,
                        ares_socket_t write_fd)
 {
-  struct timeval now = ares__tvnow();
+  struct timeval now;
 
+  if (channel == NULL) {
+    return;
+  }
+
+  ares__channel_lock(channel);
+
+  now = ares__tvnow();
   read_packets(channel, read_fds, read_fd, &now);
   process_timeouts(channel, &now);
   /* Write last as the other 2 operations might have triggered writes */
   write_tcp_data(channel, write_fds, write_fd);
+
+  ares__channel_unlock(channel);
 }
 
 /* Something interesting happened on the wire, or there was a timeout.
@@ -714,6 +724,12 @@ static ares_status_t process_answer(ares_channel_t      *channel,
     }
   }
 
+  /* If cache insertion was successful, it took ownership.  We ignore
+   * other cache insertion failures. */
+  if (ares_qcache_insert(channel, now, query, rdnsrec) == ARES_SUCCESS) {
+    rdnsrec = NULL;
+  }
+
   server_set_good(server);
   end_query(channel, query, ARES_SUCCESS, abuf, alen);
 
@@ -770,8 +786,9 @@ static struct server_state *ares__random_server(ares_channel_t *channel)
   size_t              num_servers = ares__slist_len(channel->servers);
 
   /* Silence coverity, not possible */
-  if (num_servers == 0)
-    num_servers = 1;
+  if (num_servers == 0) {
+    return NULL;
+  }
 
   ares__rand_bytes(channel->rand_state, &c, 1);
 
@@ -805,14 +822,14 @@ static ares_status_t ares__append_tcpbuf(struct server_state *server,
 
 static size_t ares__calc_query_timeout(const struct query *query)
 {
-  const ares_channel_t *channel     = query->channel;
-  size_t                timeplus    = channel->timeout;
+  const ares_channel_t *channel  = query->channel;
+  size_t                timeplus = channel->timeout;
   size_t                rounds;
   size_t                num_servers = ares__slist_len(channel->servers);
 
-  /* Silence coverity, not possible */
-  if (num_servers == 0)
-    num_servers = 1;
+  if (num_servers == 0) {
+    return 0;
+  }
 
   /* For each trip through the entire server list, we want to double the
    * retry from the last retry */
@@ -872,6 +889,11 @@ ares_status_t ares__send_query(struct query *query, struct timeval *now)
     server = ares__slist_first_val(channel->servers);
   }
 
+  if (server == NULL) {
+    end_query(channel, query, ARES_ESERVFAIL /* ? */, NULL, 0);
+    return ARES_ECONNREFUSED;
+  }
+
   if (query->using_tcp) {
     size_t prior_len = 0;
     /* Make sure the TCP socket for this server is set up and queue
